Module sync

Module sync 

GPU completion, and handing it to something outside this process.

Constants

FRAME_WAIT_TIMEOUT
How long a frame-loop wait should tolerate before it is considered a hang.

Traits

HalFence
A signal that GPU work has completed.